==> hs-mysql-0.1.1.1.tbz: lib/ghc-7.0.3/cabal/mysql-0.1.1.1/register.sh <==
#!/bin/sh
echo 'name: mysql
version: 0.1.1.1
id: mysql-0.1.1.1-f9a96a0b3e9801548069a276268b1d81

license: BSD3
copyright: 2011 MailRank, Inc.
maintainer: Bryan O'\''Sullivan <bos@mailrank.com>
stability:
homepage: https://github.com/mailrank/mysql
package-url:
description: A low-level client library for the MySQL database, implemented as
             bindings to the C @mysqlclient@ API.
             .
             /Important licensing note/: This library is BSD-licensed under the
             terms of the MySQL FOSS License Exception
             <http://www.mysql.com/about/legal/licensing/foss-exception/>.
             .
             Since this library links against the GPL-licensed @mysqlclient@
             library, a non-open-source application that uses it /may/ be
             subject to the terms of the GPL.
category: Database
author: Bryan O'\''Sullivan <bos@mailrank.com>
exposed: True
exposed-modules: Database.MySQL.Base Database.MySQL.Base.C
                 Database.MySQL.Base.Types
hidden-modules:
import-dirs: /usr/local/lib/ghc-7.0.3/cabal/mysql-0.1.1.1
library-dirs: /usr/local/lib/ghc-7.0.3/cabal/mysql-0.1.1.1
              /usr/local/lib/mysql /usr/local/lib
hs-libraries: HSmysql-0.1.1.1
extra-libraries: mysqlclient z m
extra-ghci-libraries:
include-dirs: /usr/local/include/mysql /usr/local/include
includes:
depends: base-4.3.1.0-63fd52d9e7e39016c91be0baf3543757
         bytestring-0.9.1.10-94a0a1c920aee21a485bdf21fd51b2be
         containers-0.4.0.0-8781485edb2ac0db733a9f9c72e27945
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.3/cabal/mysql-0.1.1.1/html/mysql.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.3/cabal/mysql-0.1.1.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-mysql-0.1.1.3.tbz: lib/ghc-7.0.4/cabal/mysql-0.1.1.3/register.sh <==
#!/bin/sh
echo 'name: mysql
version: 0.1.1.3
id: mysql-0.1.1.3-e1c7fee99653ae0b0951f9f37ca41799

license: BSD3
copyright: 2011 MailRank, Inc.
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
stability:
homepage: https://github.com/bos/mysql
package-url:
description: A low-level client library for the MySQL database, implemented as
             bindings to the C @mysqlclient@ API.
             .
             /Important licensing note/: This library is BSD-licensed under the
             terms of the MySQL FOSS License Exception
             <http://www.mysql.com/about/legal/licensing/foss-exception/>.
             .
             Since this library links against the GPL-licensed @mysqlclient@
             library, a non-open-source application that uses it /may/ be
             subject to the terms of the GPL.
category: Database
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules: Database.MySQL.Base Database.MySQL.Base.C
                 Database.MySQL.Base.Types
hidden-modules:
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/mysql-0.1.1.3
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/mysql-0.1.1.3
              /usr/local/lib/mysql /usr/local/lib
hs-libraries: HSmysql-0.1.1.3
extra-libraries: mysqlclient z m
extra-ghci-libraries:
include-dirs: /usr/local/include/mysql /usr/local/include
includes:
depends: base-4.3.1.0-c683e1c476645dcbab1b168f8e5a9aeb
         bytestring-0.9.1.10-94a0a1c920aee21a485bdf21fd51b2be
         containers-0.4.0.0-8781485edb2ac0db733a9f9c72e27945
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/mysql-0.1.1.3/html/mysql.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/mysql-0.1.1.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
